#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-KEiv8AIv8m64Upe3z2ilF1
key:                  haskell-language-server-2.3.0.0-KEiv8AIv8m64Upe3z2ilF1
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  85aa9935d723f358d3c9c0ecb78adfd6
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-KEiv8AIv8m64Upe3z2ilF1
depends:
    aeson-pretty-0.8.11-K65fmq2okvn2EFxMbX7n2v
    async-2.2.6-Cc2ylPSJ9T994nMR0Eaxyq base-4.18.2.1
    base16-bytestring-1.0.2.0-HKNPUjeO8LQ9RSeGAokMwf
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-EYRlHYNpqN36EzjsucJ4qd
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG directory-1.3.8.5
    extra-1.7.16-J2nH1si97LP2pkcRW1gnIU filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-3yCQsM3sLNi5mOrqFn1d0d
    githash-0.1.7.0-Gzf3QnhC8Vu2bLBSBbLufk
    hie-bios-0.12.0-vJNrBLfvg08u6r8efKftA
    hiedb-0.4.3.0-Ko0oMqKlCE3HsM5SK0VCr1
    hls-alternate-number-format-plugin-2.3.0.0-KBSksVxHddb9HvkHB8bAR0
    hls-cabal-fmt-plugin-2.3.0.0-GqmXQPt23FCpea4XOh8Eg
    hls-cabal-plugin-2.3.0.0-3gdhDtCuZG0EABPzG8zv2t
    hls-call-hierarchy-plugin-2.3.0.0-HcUGxeu5hKaq0r0haT9kd
    hls-change-type-signature-plugin-2.3.0.0-Kte31zB5K51Jo35RejctQi
    hls-class-plugin-2.3.0.0-15uPJE9g7FvIUIkdRheQsB
    hls-code-range-plugin-2.3.0.0-Liwdw4N0a5a9XbIb8Bj0zv
    hls-eval-plugin-2.3.0.0-2j6FacwsjdK6QFAca4pNZ9
    hls-explicit-fixity-plugin-2.3.0.0-IsSfc2Nf8o25QgeEOG0JYm
    hls-explicit-imports-plugin-2.3.0.0-IqLhLOvv9hg936644CErxA
    hls-explicit-record-fields-plugin-2.3.0.0-GA14lSC7yff5vfywjBuZFJ
    hls-fourmolu-plugin-2.3.0.0-OSzXwQLevrEracJWFHm6z
    hls-gadt-plugin-2.3.0.0-GiFNvirnko33zrsAaolb1
    hls-graph-2.3.0.0-EU51DDfcYUwD92bxTtun9V
    hls-hlint-plugin-2.3.0.0-GBkaCkQEFoUAfPTg6xqS09
    hls-module-name-plugin-2.3.0.0-LKJWtP8pk5NqBMganPXXE
    hls-ormolu-plugin-2.3.0.0-JuFMXvW5bnMKdOErQ1kBjj
    hls-overloaded-record-dot-plugin-2.3.0.0-AGLXFsivYOxCI1vbFmCVNQ
    hls-plugin-api-2.3.0.0-AhlgRZkAJwO1JNQXcdgGea
    hls-pragmas-plugin-2.3.0.0-HlcV3tHy1WYJ0soyMe0lia
    hls-qualify-imported-names-plugin-2.3.0.0-AQYyU6PmuLw4G7GalN57Ux
    hls-refactor-plugin-2.3.0.0-qjoxulwz3Q88D2fu83ovw
    hls-rename-plugin-2.3.0.0-1BLqBEEujqcCvUG1jWrcMa
    hls-retrie-plugin-2.3.0.0-65fbDplgZQB3hsuR5b27nC
    hls-splice-plugin-2.3.0.0-1HWVh3KTOWlK4BIXlmGSl0
    hls-stylish-haskell-plugin-2.3.0.0-3GhT1iAFIOz2mBtDXOlIb2
    lsp-2.2.0.0-JJwazOJIAzCJL4eJNeKzRs
    optparse-applicative-0.18.1.0-2OPlFtvlr5yI8qFRB5F8bn
    optparse-simple-0.1.1.4-6yyKG2PP9WN5OyDvDQyo34
    prettyprinter-1.7.2-JipenGj1ZXCGzFGneLGC87 process-1.6.19.0
    safe-exceptions-0.1.7.4-EJ1HOjDpf87Jv7v1DsVVOt
    sqlite-simple-0.4.19.0-IuZ0Ce3SMCbLEYdJYMKdFR text-2.0.2
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

